/*
calc_network_fe.do
by: Attila Gyetvai

calculates average AKM worker and match FEs in networks
*/


forval tt = 61/96 {    // scope for parallelizing here (not possible on CERS Databank server)
	di `tt'
	use "${path_build_aux}/displaced.dta", clear
	
	
*-- save coworkers
	merge m:1 anon firm using "${path_build_aux}/fe.dta", keep(match master) nogen
	keep anon t firm anonfe matchfe
	ren anon anon_cw
	ren anonfe anonfe_cw
	ren matchfe matchfe_cw
	keep if t>=`tt'-60 & t<`tt'
	save "${path_build_aux}/coworkers_t`tt'.dta", replace
	

*-- save worker pairs
	use "${path_build_aux}/displaced.dta", clear
	tempvar tmp2a tmp2b
	gen `tmp2a' = (displaced) & t==`tt'
	bysort anon (t): gegen `tmp2b' = max(`tmp2a')
	keep if (`tmp2b')
	keep if t>=`tt'-60 & t<`tt'
	
* save coworkers in temporary file
	qui levels firm, local(firm_uniq)
	preserve
	tempfile coworkers
	use "${path_build_aux}/coworkers_t`tt'.dta", clear
	tempvar flag
	gen `flag' = 0
	foreach fid of local firm_uniq {
		replace `flag' = 1 if firm==`fid'
	}
	keep if (`flag')
	save "`coworkers'"
	restore
	
* join displaced workers and former coworkers
	joinby firm t using `coworkers', update unmatched(master)
	cap drop  __00*
	cap drop _merge
	drop if missing(anon)
	drop if missing(anon_cw)
	drop if anon==anon_cw
	gsort anon_cw anon t    // GSORT
	save "${path_build_aux}/joinby_t`tt'.dta", replace
	use "${path_build_aux}/joinby_t`tt'.dta", clear
	
	
*-- calculate average AKM FEs in network
	bysort anon (t anon_cw): gegen anonfe_network = mean(anonfe_cw)
	bysort anon (t anon_cw): gegen matchfe_network = mean(matchfe_cw)
	

*-- save data by displacement time
	bysort anon (t anon_cw): keep if _n==1
	local vars "anonfe_network matchfe_network"
	keep anon `vars'
	gen t = `tt'
	order anon t `vars'
	save "${path_build_aux}/network_fe_t`tt'.dta", replace
	erase "${path_build_aux}/coworkers_t`tt'.dta"
	erase "${path_build_aux}/joinby_t`tt'.dta"

}    // end of parallelization if applicable


*-- save network measures
use "${path_build_aux}/network_fe_t61.dta", replace
forval tt = 62/96 {
	append using "${path_build_aux}/network_fe_t`tt'.dta"
}
save "${path_build_aux}/network_fe.dta", replace
forval tt = 61/96 {
	erase "${path_build_aux}/network_fe_t`tt'.dta"
}


*-- end code
