/*
calc_network_measures.do
by: Attila Gyetvai

calculates network measures
*/


forval tt = 61/96 {    // scope for parallelizing here (not possible on server)
	di `tt'
	use "${path_build_aux}/displaced.dta", clear
	
*-- save coworkers
	keep anon t firm occ_4 E displaced
	ren anon anon_cw
	ren occ_4 occ_4_cw
	ren E E_cw
	ren displaced displaced_cw
	tempvar tmp1
	gen `tmp1' = E_cw & t==`tt'
	bysort anon (t): gegen E_cw_t`tt' = max(`tmp1')
	keep if t>=`tt'-60 & t<`tt'
	save "${path_build_aux}/coworkers_t`tt'.dta", replace
	

*-- save worker pairs
	use "${path_build_aux}/displaced.dta", clear
	tempvar tmp2a tmp2b
	gen `tmp2a' = (displaced) & t==`tt'
	bysort anon (t): gegen `tmp2b' = max(`tmp2a')
	keep if (`tmp2b')
	keep if t>=`tt'-60 & t<`tt'
	
* save coworkers in temporary file
	qui levels firm, local(firm_uniq)
	preserve
	tempfile coworkers
	use "${path_build_aux}/coworkers_t`tt'.dta", clear
	tempvar flag
	gen `flag' = 0
	foreach fid of local firm_uniq {
		replace `flag' = 1 if firm==`fid'
	}
	keep if (`flag')
	save "`coworkers'"
	restore
	
* join displaced workers and former coworkers
	joinby firm t using `coworkers', update unmatched(master)
	cap drop  __00*
	cap drop _merge
	drop if missing(anon)
	drop if missing(anon_cw)
	drop if anon==anon_cw
	gsort anon_cw anon t    // GSORT
	save "${path_build_aux}/joinby_t`tt'.dta", replace
	use "${path_build_aux}/joinby_t`tt'.dta", clear

	
*-- generate 4-digit occupations
	gen occ_1 = floor(occ_4/1000)
	gen occ_2 = floor(occ_4/100)
	gen occ_3 = floor(occ_4/10)
	gen occ_1_cw = floor(occ_4_cw/1000)
	gen occ_2_cw = floor(occ_4_cw/100)
	gen occ_3_cw = floor(occ_4_cw/10)
	

*-- same/diff occ coworkers
	forval oo = 1/4 {
		gen same`oo' = occ_`oo'==occ_`oo'_cw if !missing(occ_`oo') & !missing(occ_`oo'_cw)
		gen diff`oo' = occ_`oo'!=occ_`oo'_cw if !missing(occ_`oo') & !missing(occ_`oo'_cw)
	}
	
	
*-- recent/non-recent coworkers
	foreach rr of numlist 12 24 {
		tempvar lasttime
		bysort anon anon_cw (t): egen `lasttime' = max(t)
		gen rcnt`rr' = `tt'-`lasttime'<`rr'
		gen oldr`rr' = `tt'-`lasttime'>=`rr'
	}

	
*-- coworkers mass layoff instrument (a la Glitz, 2017)
	gsort anon t anon_cw    // GSORT
	tempvar M_tmp E_tmp Z_tmp
	bysort anon t (anon_cw): gegen `M_tmp' = total(displaced_cw)
	bysort anon t (anon_cw): gegen `E_tmp' = total(E_cw)
	gen `Z_tmp' = `M_tmp'/`E_tmp'
	bysort anon (t anon_cw): gegen Z = total(`Z_tmp')
	
* same/diff occ
	forval oo = 1/4 {
		tempvar M_tmp E_tmp Z_tmp
		bysort anon t (anon_cw): gegen `M_tmp' = total(displaced_cw) if (same`oo')
		bysort anon t (anon_cw): gegen `E_tmp' = total(E_cw) if (same`oo')
		gen `Z_tmp' = `M_tmp'/`E_tmp'
		bysort anon (t anon_cw): gegen Z_same`oo' = total(`Z_tmp')
		
		tempvar M_tmp E_tmp Z_tmp
		bysort anon t (anon_cw): gegen `M_tmp' = total(displaced_cw) if (diff`oo')
		bysort anon t (anon_cw): gegen `E_tmp' = total(E_cw) if (diff`oo')
		gen `Z_tmp' = `M_tmp'/`E_tmp'
		bysort anon (t anon_cw): gegen Z_diff`oo' = total(`Z_tmp')
	}
	
* recency
	foreach rr of numlist 12 24 {
		tempvar M_tmp E_tmp Z_tmp
		bysort anon t (anon_cw): gegen `M_tmp' = total(displaced_cw) if (rcnt`rr')
		bysort anon t (anon_cw): gegen `E_tmp' = total(E_cw) if (rcnt`rr')
		gen `Z_tmp' = `M_tmp'/`E_tmp'
		bysort anon (t anon_cw): gegen Z_rcnt`rr' = total(`Z_tmp')
		
		tempvar M_tmp E_tmp Z_tmp
		bysort anon t (anon_cw): gegen `M_tmp' = total(displaced_cw) if (oldr`rr')
		bysort anon t (anon_cw): gegen `E_tmp' = total(E_cw) if (oldr`rr')
		gen `Z_tmp' = `M_tmp'/`E_tmp'
		bysort anon (t anon_cw): gegen Z_oldr`rr' = total(`Z_tmp')
	}
	
* occ X recency
	forval oo = 1/4 {
		foreach rr of numlist 12 24 {
			tempvar M_tmp E_tmp Z_tmp
			bysort anon t (anon_cw): gegen `M_tmp' = total(displaced_cw) if (same`oo') & (rcnt`rr')
			bysort anon t (anon_cw): gegen `E_tmp' = total(E_cw) if (same`oo') & (rcnt`rr')
			gen `Z_tmp' = `M_tmp'/`E_tmp'
			bysort anon (t anon_cw): gegen Z_same`oo'_rcnt`rr' = total(`Z_tmp')
			
			tempvar M_tmp E_tmp Z_tmp
			bysort anon t (anon_cw): gegen `M_tmp' = total(displaced_cw) if (diff`oo') & (rcnt`rr')
			bysort anon t (anon_cw): gegen `E_tmp' = total(E_cw) if (diff`oo') & (rcnt`rr')
			gen `Z_tmp' = `M_tmp'/`E_tmp'
			bysort anon (t anon_cw): gegen Z_diff`oo'_rcnt`rr' = total(`Z_tmp')
			
			tempvar M_tmp E_tmp Z_tmp
			bysort anon t (anon_cw): gegen `M_tmp' = total(displaced_cw) if (same`oo') & (oldr`rr')
			bysort anon t (anon_cw): gegen `E_tmp' = total(E_cw) if (same`oo') & (oldr`rr')
			gen `Z_tmp' = `M_tmp'/`E_tmp'
			bysort anon (t anon_cw): gegen Z_same`oo'_oldr`rr' = total(`Z_tmp')
			
			tempvar M_tmp E_tmp Z_tmp
			bysort anon t (anon_cw): gegen `M_tmp' = total(displaced_cw) if (diff`oo') & (oldr`rr')
			bysort anon t (anon_cw): gegen `E_tmp' = total(E_cw) if (diff`oo') & (oldr`rr')
			gen `Z_tmp' = `M_tmp'/`E_tmp'
			bysort anon (t anon_cw): gegen Z_diff`oo'_oldr`rr' = total(`Z_tmp')
		}
	}
	
	
*-- calculate network measures	
* reduce data (enough to keep only time of displacement)
	gduplicates drop anon anon_cw, force
	
* employment rate
	bysort anon (t anon_cw): gegen er = mean(E_cw_t`tt')
	
* network size
	bysort anon (t anon_cw): gegen N = count(E_cw_t`tt')
	
* same/diff occ
	forval oo = 1/4 {
		tempvar er_1_tmp er_2_tmp N_1_tmp N_2_tmp
		bysort anon (t anon_cw): gegen `er_1_tmp' = mean(E_cw_t`tt') if (same`oo')
		bysort anon (t anon_cw): gegen `er_2_tmp' = mean(E_cw_t`tt') if (diff`oo')
		bysort anon (t anon_cw): gegen `N_1_tmp' = count(E_cw_t`tt') if (same`oo')
		bysort anon (t anon_cw): gegen `N_2_tmp' = count(E_cw_t`tt') if (diff`oo')
		
		bysort anon (t anon_cw): gegen er_same`oo' = mean(`er_1_tmp')
		bysort anon (t anon_cw): gegen er_diff`oo' = mean(`er_2_tmp')
		bysort anon (t anon_cw): gegen N_same`oo' = mean(`N_1_tmp')
		bysort anon (t anon_cw): gegen N_diff`oo' = mean(`N_2_tmp')
		
		replace N_same`oo' = 0 if missing(N_same`oo')
		replace N_diff`oo' = 0 if missing(N_diff`oo')
	}
	
* recency
	foreach rr of numlist 12 24 {
		tempvar er_1_tmp er_2_tmp N_1_tmp N_2_tmp
		bysort anon (t anon_cw): gegen `er_1_tmp' = mean(E_cw_t`tt') if (rcnt`rr')
		bysort anon (t anon_cw): gegen `er_2_tmp' = mean(E_cw_t`tt') if (oldr`rr')
		bysort anon (t anon_cw): gegen `N_1_tmp' = count(E_cw_t`tt') if (rcnt`rr')
		bysort anon (t anon_cw): gegen `N_2_tmp' = count(E_cw_t`tt') if (oldr`rr')
		
		bysort anon (t anon_cw): gegen er_rcnt`rr' = mean(`er_1_tmp')
		bysort anon (t anon_cw): gegen er_oldr`rr' = mean(`er_2_tmp')
		bysort anon (t anon_cw): gegen N_rcnt`rr' = mean(`N_1_tmp')
		bysort anon (t anon_cw): gegen N_oldr`rr' = mean(`N_2_tmp')
		
		replace N_rcnt`rr' = 0 if missing(N_rcnt`rr')
		replace N_oldr`rr' = 0 if missing(N_oldr`rr')
	}
	
* occ X recency
	forval oo = 1/4 {
		foreach rr of numlist 12 24 {
			tempvar er_1_tmp er_2_tmp er_3_tmp er_4_tmp N_1_tmp N_2_tmp N_3_tmp N_4_tmp
			bysort anon (t anon_cw): gegen `er_1_tmp' = mean(E_cw_t`tt') if (same`oo') & (rcnt`rr')
			bysort anon (t anon_cw): gegen `er_2_tmp' = mean(E_cw_t`tt') if (diff`oo') & (rcnt`rr')
			bysort anon (t anon_cw): gegen `er_3_tmp' = mean(E_cw_t`tt') if (same`oo') & (oldr`rr')
			bysort anon (t anon_cw): gegen `er_4_tmp' = mean(E_cw_t`tt') if (diff`oo') & (oldr`rr')
			bysort anon (t anon_cw): gegen `N_1_tmp' = count(E_cw_t`tt') if (same`oo') & (rcnt`rr')
			bysort anon (t anon_cw): gegen `N_2_tmp' = count(E_cw_t`tt') if (diff`oo') & (rcnt`rr')
			bysort anon (t anon_cw): gegen `N_3_tmp' = count(E_cw_t`tt') if (same`oo') & (oldr`rr')
			bysort anon (t anon_cw): gegen `N_4_tmp' = count(E_cw_t`tt') if (diff`oo') & (oldr`rr')
			
			bysort anon (t anon_cw): gegen er_same`oo'_rcnt`rr' = mean(`er_1_tmp')
			bysort anon (t anon_cw): gegen er_diff`oo'_rcnt`rr' = mean(`er_2_tmp')
			bysort anon (t anon_cw): gegen er_same`oo'_oldr`rr' = mean(`er_3_tmp')
			bysort anon (t anon_cw): gegen er_diff`oo'_oldr`rr' = mean(`er_4_tmp')
			bysort anon (t anon_cw): gegen N_same`oo'_rcnt`rr' = mean(`N_1_tmp')
			bysort anon (t anon_cw): gegen N_diff`oo'_rcnt`rr' = mean(`N_2_tmp')
			bysort anon (t anon_cw): gegen N_same`oo'_oldr`rr' = mean(`N_3_tmp')
			bysort anon (t anon_cw): gegen N_diff`oo'_oldr`rr' = mean(`N_4_tmp')
			
			replace N_same`oo'_rcnt`rr' = 0 if missing(N_same`oo'_rcnt`rr')
			replace N_diff`oo'_rcnt`rr' = 0 if missing(N_diff`oo'_rcnt`rr')
			replace N_same`oo'_oldr`rr' = 0 if missing(N_same`oo'_oldr`rr')
			replace N_diff`oo'_oldr`rr' = 0 if missing(N_diff`oo'_oldr`rr')
		}
	}

	
*-- save data by displacement time
	bysort anon (t anon_cw): keep if _n==1
	local vars "occ_* er er_* N N_* Z Z_*"
	keep anon `vars'
	drop *_cw
	gen t = `tt'
	order anon t `vars'
	save "${path_build_aux}/network_measures_t`tt'.dta", replace
	erase "${path_build_aux}/coworkers_t`tt'.dta"
	erase "${path_build_aux}/joinby_t`tt'.dta"

}    // end of parallelization if applicable


*-- save network measures
use "${path_build_aux}/network_measures_t61.dta", replace
forval tt = 62/96 {
	append using "${path_build_aux}/network_measures_t`tt'.dta"
}
save "${path_build_aux}/network_measures.dta", replace
forval tt = 61/96 {
	erase "${path_build_aux}/network_measures_t`tt'.dta"
}


*-- end code
