/*
flag_displaced.do
by: Attila Gyetvai

saves the data of displaced workers
*/


*-- load worker data
use anon t ev ferfi kor vallazon* w w_* nap nap_* fogvisz* transzfer1 ///
	using "${path_raw_data}/AdminII_alap.dta", clear
ren ev year
gen female = 1-ferfi
drop ferfi
ren kor age
ren vallazon* firm_*
ren nap days
ren nap_* days_*
ren fogvisz* status_*
ren transzfer1 transfer_1
gsort anon t

* keep if ever worked full time for positive wage
tempvar flag1 hist1
gen `flag1' = !missing(w) & w>0 & status_1==201
bysort anon (t): gegen `hist1' = max(`flag1')
keep if `hist1'

* merge occupations
merge 1:1 anon t using "${path_raw_data}/feor.dta", ///
	keepusing(feor1_2003_4 feor2_2003_4) keep(master match) nogen
ren feor1_2003_4 occ_4_1
ren feor2_2003_4 occ_4_2
gsort anon t
tempvar tmpv2
bysort anon (t): gegen `tmpv2' = max(occ_4_1)
keep if !missing(`tmpv2')

* switch 1st/2nd work arrangements
global vars_to_switch "w_ days_ status_ occ_4_"
do "${path_build_aux}/switchit"

* patch monthly/yearly gaps in work histories
do "${path_build_aux}/patchit"

* keep 1st job only
ren firm_1 firm
ren occ_4_1 occ_4
ren status_1 status
drop *_2
drop transfer*


*-- fill firm IDs 
/*
case A:
w   w_1  firm
10  10   A
5   .    .
.   .    .

case B:
w   w_1  firm
.   .    .
5   .    .
10  10   A
*/
replace firm = firm[_n-1] if anon[_n-1]==anon & anon==anon[_n+1] ///    case A
	& !missing(w[_n-1]) & !missing(w) & missing(w[_n+1]) & w[_n-1]>0 & w>0 ///
	& !missing(w_1[_n-1]) & missing(w_1) & missing(w_1[_n+1]) & w_1[_n-1]>0 ///
	& !missing(firm[_n-1]) & missing(firm) & missing(firm[_n+1]) 
replace firm = firm[_n+1] if anon[_n-1]==anon & anon==anon[_n+1] ///    case B
	& missing(w[_n-1]) & !missing(w) & missing(w[_n+1]) & w>0 & w[_n+1]>0 ///
	& missing(w_1[_n-1]) & missing(w_1) & !missing(w_1[_n+1]) & w_1[_n+1]>0 ///
	& missing(firm[_n-1]) & missing(firm) & !missing(firm[_n+1])


*-- generate labor force status and transitions
gen E = !missing(w)
gen U = !E
gen JJ = anon==anon[_n-1] & E & E[_n-1] & !missing(firm) ///
	& !missing(firm[_n-1]) & firm!=firm[_n-1]
gen EU = anon==anon[_n-1] & U & E[_n-1]
gen UE = anon==anon[_n-1] & E & U[_n-1]


*-- merge firm data
ren firm vallazon
merge m:1 vallazon year using "${path_raw_firm}/vall_pan_szerver_17.dta", ///
	keepusing(size kilep acquisition) keep(master match) nogen
ren vallazon firm
ren size firm_size
ren kilep firm_exit 
gsort anon t

* identify firm closures
gen firm_closure = 0
replace firm_closure = 1 if firm_exit>=2008 & firm_exit<=2010
replace firm_closure = 0 if (acquisition)
replace firm_closure = 0 if firm_size<10


*-- identify displaced workers
gsort anon t
gen displaced = (firm_closure) & firm_exit==year & (EU[_n+1]|JJ[_n+1])

* not displaced if 50% move together to new firm
tempvar size_old size_new firm_new
gsort anon t
gen `firm_new' = firm[_n+1] if anon==anon[_n+1] & (displaced) & (JJ[_n+1])
bysort firm t: gegen `size_old' = count(anon)
replace `size_old' = . if missing(firm)
gsort firm `firm_new' t
bysort firm `firm_new' t: gegen `size_new' = count(anon)
replace `size_new' = . if missing(`firm_new')
gsort anon t
replace displaced = 0 if `size_new'/`size_old'>0.5 & !missing(`size_new')
* drop if displaced more than once in 2008-2010
tempvar tmpv3
bysort anon (t): gegen `tmpv3' = sum(displaced) if year>=2008 & year<=2010
drop if !missing(`tmpv3') & `tmpv3'>1


*-- save displaced data
keep anon year t age female firm w w_1 days days_1 occ_4 status ///
	E U JJ EU UE firm_size acquisition firm_exit firm_closure ///
	displaced
	
* remove var labels
foreach var of varlist _all {
	la var `var'
}


*-- save displaced data
keep anon year t age female firm w w_1 days days_1 occ_4 status ///
	E U JJ EU UE firm_size acquisition firm_exit firm_closure ///
	displaced
	
* remove var labels
foreach var of varlist _all {
	la var `var'
}

save "${path_build_aux}/displaced.dta", replace


*-- end code
