/*
create_sumstats.do
by: Attila Gyetvai

calculates summary statistics
*/


*-- initialize
cls
set more off
est clear

* paths
global path_root          ""    // local root directory
global path_build         "${path_root}/build"
global path_build_aux     "${path_build}/aux"
global path_calcs         "${path_root}/calcs"
global path_clean         "${path_calcs}/clean_data"
global path_results       "${path_root}/results"
global path_graphs        "${path_results}/graphs"
global path_tables        "${path_results}/tables"
cd "${path_build}"

use "${path_clean}/sample.dta", clear


*-- text: worker, firm counts
gunique anon if year==2008
gunique firm if year==2008
gunique anon
gunique firm


*-- table 3.1: summary stats
gen firm_size_pre_exp = exp(firm_size_pre)
gen w_pre_usd = exp(w_pre)/275.48*1.3257    // exchange rate from https://www.ksh.hu/docs/hun/eurostat_tablak/tabl/tec00033.html
gen durU_rc = durU+t==107
estpost su female age w_pre_usd w_growth_pre firm_size_pre_exp tenure durU job1m_post job6m_post job12m_post er er_same4 N N_same4, det
esttab . using "${path_tables}/sumstats.tex", replace ///
	cells("p25(fmt(3)) p50(fmt(3)) p75(fmt(3)) mean(fmt(3)) sd(fmt(3))") noobs ///
	style(tex)
su durU if year==2008, det
	
estpost tabstat female age w_pre_usd w_growth_pre firm_size_pre_exp tenure durU job1m_post job6m_post job12m_post er er_same4 N N_same4, by(educ) statistics(mean p50) columns(statistics) listwise
esttab . using "${path_tables}/sumstats_educ.tex", replace ///
	cells("mean(fmt(3)) p50(fmt(3))") unstack noobs nostar nonote style(tex)
estpost tabstat durU if year==2008, by(educ) statistics(mean p50) columns(statistics) listwise


*-- figure 3.1: binscatters for U duration and network employment rate
* U duration
binscatter durU er_same4 if er_same4>0.2 & er_same4<1 & year==2008, xtitle("Network employment rate (same occupation)") ytitle("Unemployment duration (month)") xlabel(#6)
graph export "${path_graphs}/durU_ersame.pdf", replace as(pdf) name("Graph")
binscatter durU er_diff4 if er_diff4>0.2 & er_same4<1 & year==2008, xtitle("Network employment rate (different occupation)") ytitle("Unemployment duration (month)") xlabel(#6)
graph export "${path_graphs}/durU_erdiff.pdf", replace as(pdf) name("Graph")


*-- appendix figure A.2: job finding prob
cap program drop jobxm_er_bs
program jobxm_er_bs
	args m l h s
	binscatter job`m'm_post er_same4 if er_same4>0.2 & er_same4<1, xtitle("Network employment rate (same occupation)") ytitle("Pr(U duration < `m' month)") ///
		xscale(range(0.5 1)) yscale(range(`l' `h')) xlabel(#6) ylabel(`l'(`s')`h')
	graph export "${path_graphs}/job`m'm_ersame.pdf", replace as(pdf) name("Graph")
	binscatter job`m'm_post er_diff4 if er_diff4>0.2 & er_same4<1, xtitle("Network employment rate (different occupation)") ytitle("Pr(U duration < `m' month)") ///
		xscale(range(0.5 1)) yscale(range(`l' `h')) xlabel(#6) ylabel(`l'(`s')`h')
	graph export "${path_graphs}/job`m'm_erdiff.pdf", replace as(pdf) name("Graph")
end
jobxm_er_bs 1 0.3 0.45 0.05
jobxm_er_bs 3 0.4 0.55 0.05
jobxm_er_bs 6 0.525 0.65 0.025
	
	
*-- appendix table A.1: distribution of 1-digit occs
tab occ_1 if occ_1>0


*-- appendix table A.2: most prevalent 4-digit occs
tab occ_4, sort nolab


*-- appendix table A.3: network size by occupation and educ
forval educ = 1/3 {
	qui su N_same4x if educ==`educ', det
	di r(mean)
	di r(p50)
	qui su N_same3x if educ==`educ', det
	di r(mean)
	di r(p50)
	qui su N_same2x if educ==`educ', det
	di r(mean)
	di r(p50)
	qui su N_same1x if educ==`educ', det
	di r(mean)
	di r(p50)
	qui su N_diff1 if educ==`educ', det
	di r(mean)
	di r(p50)
}


*-- appendix table A.4: post-displacement outcomes by educ
tab educ if year==2008, sum(durU)
tab educ, sum(occstay_post)
	

*-- end code
