/*
estimate_models_aux.do
by: Attila Gyetvai

estimates additional models and saves the results
*/


*-- initialize
cls
set more off
est clear

* paths
global path_root          ""    // local root directory
global path_build         "${path_root}/build"
global path_build_aux     "${path_build}/aux"
global path_calcs         "${path_root}/calcs"
global path_clean         "${path_calcs}/clean_data"
global path_results       "${path_root}/results"
global path_tables        "${path_results}/tables"
global path_graphs        "${path_results}/graphs"
cd "${path_build}"

cap log close
log using "${path_results}/estimate_models_aux.log", replace

use "${path_clean}/sample.dta", clear

* putexcel
putexcel clear
putexcel set "${path_results}/pr_e_months.xlsx", modify
global r_i = 2    // row index for regression results; 1 is header
putexcel A1 = "er"
putexcel B1 = "er_ci_lo"
putexcel C1 = "er_ci_hi"
putexcel D1 = "ersame4"
putexcel E1 = "ersame4_ci_lo"
putexcel F1 = "ersame4_ci_hi"

* controls
local Xd "female age age2 tenure tenure2"
local Xi "w_pre w_growth_pre ur_pre"
local Xj "firm_size_pre firm_count_pre_cat_*"
local Xfe "anonfe_network matchfe_network"



// TABLES IN RESPONSE LETTER 1 //

*-- response table 1: AKM match quality after displacement
reghdfe dfirmfe er er_same4 logN logN_same4 mis mis_same4 `Xd' `Xi' `Xj' `Xfe', absorb(lambda eta_4 sec_pre) vce(cluster firm)
est sto rtab1_1
estadd local akmfe "Y", replace
estadd local pofe "Y" , replace
estadd local psfe "Y" , replace
estadd local cffe "Y" , replace

reghdfe dmatchfe er er_same4 logN logN_same4 mis mis_same4 `Xd' `Xi' `Xj' `Xfe', absorb(lambda eta_4 sec_pre) vce(cluster firm)
est sto rtab1_2
estadd local akmfe "Y", replace
estadd local pofe "Y" , replace
estadd local psfe "Y" , replace
estadd local cffe "Y" , replace
	
esttab rtab1_* using "${path_tables}/tab_r1.tex", replace ///
	keep(er* logN* `Xfe' `Xi' `Xj') ///
	order(er er_same* logN logN_same* `Xfe') ///
	label nomtitles nodepvars mlabels(none) collabels(none) ///
	cells(b(star fmt(3) label( )) se(par fmt(3) label( ))) ///
	starlevels(\sym{*} 0.1 \sym{**} 0.05 \sym{***} 0.01) ///
	scalars("akmfe Network AKM FEs" "cffe Closing firm FE" "pofe Pre-displacement occ.\ FE" "psfe Pre-displacement sector FE" "N \(N\)" "r2 \(R^2\)" "r2_within Within \(R^2\)") ///
	sfmt(0 0 0 3 3) ///
	style(tex) alignment(D{.}{.}{-1})
	
	
*-- response table 2: Pr(staying in occupation) on network employment rate
reghdfe occstay_post er logN mis `Xd' `Xi' `Xj' `Xfe', absorb(lambda eta_4 sec_pre) vce(cluster firm)
est sto rtab2_1
estadd local pofe "Y" , replace
estadd local psfe "Y" , replace
estadd local cffe "Y" , replace

reghdfe occstay_post er er_same4 logN logN_same4 mis mis_same4 `Xd' `Xi' `Xj' `Xfe', absorb(lambda eta_4 sec_pre) vce(cluster firm)
est sto rtab2_2
estadd local pofe "Y" , replace
estadd local psfe "Y" , replace
estadd local cffe "Y" , replace

esttab rtab2_* using "${path_tables}/tab_r2.tex", replace ///
	keep(er* logN* `Xfe' `Xi' `Xj') ///
	order(er er_same* logN logN_same* `Xfe') ///
	label nomtitles nodepvars mlabels(none) collabels(none) ///
	cells(b(star fmt(3) label( )) se(par fmt(3) label( ))) ///
	starlevels(\sym{*} 0.1 \sym{**} 0.05 \sym{***} 0.01) ///
	scalars("cffe Closing firm FE" "pofe Pre-displacement occ.\ FE" "psfe Pre-displacement sector FE" "N \(N\)" "r2 \(R^2\)" "r2_within Within \(R^2\)") ///
	sfmt(0 0 0 3 3) ///
	style(tex) alignment(D{.}{.}{-1})
	
	
*-- response table 3: U duration on network employment rate by recency
reghdfe u er er_rcnt12 er_same4 er_same4_rcnt12 logN logN_rcnt12 logN_same4 logN_same4_rcnt12 mis mis_rcnt12 mis_same4 mis_same4_rcnt12 `Xd' `Xi' `Xj' `Xfe' if year==2008, absorb(lambda eta_4 sec_pre) vce(cluster firm)
est sto rtab3_1
estadd local akmfe "Y", replace
estadd local i_pre "Y", replace
estadd local j_pre "Y", replace
estadd local psfe "Y", replace
estadd local pofe "Y", replace
estadd local cffe "Y", replace

reghdfe u er er_rcnt24 er_same4 er_same4_rcnt24 logN logN_rcnt24 logN_same4 logN_same4_rcnt24 mis mis_rcnt24 mis_same4 mis_same4_rcnt24 `Xd' `Xi' `Xj' `Xfe' if year==2008, absorb(lambda eta_4 sec_pre) vce(cluster firm)
est sto rtab3_2
estadd local akmfe "Y", replace
estadd local i_pre "Y", replace
estadd local j_pre "Y", replace
estadd local psfe "Y", replace
estadd local pofe "Y", replace
estadd local cffe "Y", replace

esttab rtab3_* using "${path_tables}/tab_r3.tex", replace ///
	keep(er*) ///
	order(er er_rcnt12 er_rcnt24 er_same4 er_same4_rcnt12 er_same4_rcnt24) ///
	label nomtitles nodepvars mlabels(none) collabels(none) ///
	cells(b(star fmt(3)) se(par fmt(3))) ///
	starlevels(\sym{*} 0.1 \sym{**} 0.05 \sym{***} 0.01) ///
	scalars("akmfe Network AKM FEs" "i_pre Pre-displacement worker characteristics" "j_pre Pre-displacement firm characteristics" "cffe Closing firm FE" "pofe Pre-displacement occ.\ FE" "psfe Pre-displacement sector FE" "N \(N\)" "r2 \(R^2\)" "r2_within Within \(R^2\)") ///
	sfmt(0 0 0 0 0 3 3) ///
	style(tex) alignment(D{.}{.}{-1})
	

*-- response table 4: Pr(finding a job within X months)
foreach mm of numlist 0 1 3 6 12 {
	reghdfe job`mm'm_post er er_same4 logN logN_same4 mis mis_same4 `Xd' `Xi' `Xj' `Xfe', ///
		absorb(lambda eta_4 sec_pre) vce(cluster firm)
	est sto rtab4_`mm'
	estadd local akmfe "Y", replace
	estadd local i_pre "Y", replace
	estadd local j_pre "Y", replace
	estadd local pofe "Y" , replace
	estadd local psfe "Y" , replace
	estadd local cffe "Y" , replace
}

esttab rtab4_* using "${path_tables}/tab_r4.tex", replace ///
	keep(er*) ///
	order(er*) ///
	label nomtitles nodepvars mlabels(none) collabels(none) ///
	cells(b(star fmt(3) label( )) se(par fmt(3) label( ))) ///
	starlevels(\sym{*} 0.1 \sym{**} 0.05 \sym{***} 0.01) ///
	scalars("akmfe Network AKM FEs" "i_pre Pre-displacement worker characteristics" "j_pre Pre-displacement firm characteristics" "cffe Closing firm FE" "pofe Pre-displacement occ.\ FE" "psfe Pre-displacement sector FE" "N \(N\)" "r2 \(R^2\)" "r2_within Within \(R^2\)") ///
	sfmt(0 0 0 3 3) ///
	style(tex) alignment(D{.}{.}{-1})
	
*-- response table 5: replicate table 3 excluding small networks
// only in 2008 so that durations are not censored
*- separate regressions
forval educ = 1/3 {
	reghdfe u er_same4x er_same3x er_same2x er_same1x er_diff1 logN c.logN#c.Nsh_same4x c.logN#c.Nsh_same3x c.logN#c.Nsh_same2x c.logN#c.Nsh_same1x mis_same1 mis_same2 mis_same3 mis_same4 mis_diff1 `Xd' `Xi' `Xj' `Xfe' if year==2008 & educ==`educ' & N_same4x>=5 & N_same3x>=5 & N_same2x>=5 & N_same1x>=5 & N_diff1>=5, absorb(lambda eta_4 sec_pre) vce(r)
	est sto rtab5_`educ'
	test er_same4x er_same3x er_same2x er_same1x
	estadd scalar F_joint = r(F)
	estadd scalar p_joint = r(p)
	estadd local akmfe "Y", replace
	estadd local i_pre "Y", replace
	estadd local j_pre "Y", replace
	estadd local psfe "Y", replace
	estadd local pofe "Y", replace
	estadd local cffe "Y", replace
}

esttab rtab5_* using "${path_tables}/tab_r5.tex", replace ///
	keep(er* logN) ///
	order(er* logN) ///
	label nomtitles nodepvars mlabels(none) collabels(none) ///
	cells(b(star fmt(3)) se(par fmt(3))) ///
	starlevels(\sym{*} 0.1 \sym{**} 0.05 \sym{***} 0.01) ///
	scalars("akmfe Network AKM FEs" "i_pre Pre-displacement worker characteristics" "j_pre Pre-displacement firm characteristics" "cffe Closing firm FE" "pofe Pre-displacement occ.\ FE" "psfe Pre-displacement sector FE" "N \(N\)" "r2 \(R^2\)" "r2_within Within \(R^2\)" "F_joint Joint \(F\)-test" "p_joint \(p\)-value") ///
	sfmt(0 0 0 0 0 3 3) ///
	style(tex) alignment(D{.}{.}{-1})

*- pooled regression across education levels, results manually exported
reghdfe u i.educ#c.(er_same4x er_same3x er_same2x er_same1x er_diff1 logN c.logN#c.Nsh_same4x c.logN#c.Nsh_same3x c.logN#c.Nsh_same2x c.logN#c.Nsh_same1x mis_same1 mis_same2 mis_same3 mis_same4 mis_diff1 `Xd' `Xi' `Xj' `Xfe') if year==2008 & N_same4x>=3 & N_same3x>=3 & N_same2x>=3 & N_same1x>=3 & N_diff1>=3, absorb(lambda eta_4 sec_pre) vce(r)
	
	
*-- response table 6: Pr(staying in occupation) on network employment rate by educ
*- separate regressions
forval educ = 1/3 {
	reghdfe occstay_post er er_same4 logN logN_same4 mis mis_same4 `Xd' `Xi' `Xj' `Xfe' if educ==`educ', absorb(lambda eta_4 sec_pre) vce(cluster firm)
	est sto rtab6_`educ'
	estadd local pofe "Y" , replace
	estadd local psfe "Y" , replace
	estadd local cffe "Y" , replace
}

esttab rtab6_* using "${path_tables}/tab_r6.tex", replace ///
	keep(er* logN* `Xfe' `Xi' `Xj') ///
	order(er er_same* logN logN_same* `Xfe') ///
	label nomtitles nodepvars mlabels(none) collabels(none) ///
	cells(b(star fmt(3) label( )) se(par fmt(3) label( ))) ///
	starlevels(\sym{*} 0.1 \sym{**} 0.05 \sym{***} 0.01) ///
	scalars("cffe Closing firm FE" "pofe Pre-displacement occ.\ FE" "psfe Pre-displacement sector FE" "N \(N\)" "r2 \(R^2\)" "r2_within Within \(R^2\)") ///
	sfmt(0 0 0 3 3) ///
	style(tex) alignment(D{.}{.}{-1})

*- pooled regression across education levels, results manually exported
reghdfe occstay_post i.educ#c.(er er_same4 logN logN_same4 mis mis_same4 `Xd' `Xi' `Xj' `Xfe'), absorb(lambda eta_4 sec_pre) vce(cluster firm)


*-- response table 7: Pr(finding a job within 1 month) on network employment rate by sectoral prevalence
reghdfe job1m_post c.(er logN)##c.occ_sec_prev mis `Xd' `Xi' `Xj' `Xfe', absorb(lambda eta_4 sec_pre) vce(cluster firm)
est sto rtab7_1
estadd local pofe "Y" , replace
estadd local psfe "Y" , replace
estadd local cffe "Y" , replace

reghdfe job1m_post c.(er er_same4 logN logN_same4)##c.occ_sec_prev mis mis_same4 `Xd' `Xi' `Xj' `Xfe', absorb(lambda eta_4 sec_pre) vce(cluster firm)
est sto rtab7_2
estadd local pofe "Y" , replace
estadd local psfe "Y" , replace
estadd local cffe "Y" , replace
	
esttab rtab7_* using "${path_tables}/tab_r7.tex", replace ///
	keep(er* logN* occ_sec_prev* c.er* c.logN* `Xfe' `Xi' `Xj') ///
	order(er er_same* logN logN_same* occ_sec_prev* c.er* c.logN* `Xfe') ///
	label nomtitles nodepvars mlabels(none) collabels(none) ///
	cells(b(star fmt(3) label( )) se(par fmt(3) label( ))) ///
	starlevels(\sym{*} 0.1 \sym{**} 0.05 \sym{***} 0.01) ///
	scalars("cffe Closing firm FE" "pofe Pre-displacement occ.\ FE" "psfe Pre-displacement sector FE" "N \(N\)" "r2 \(R^2\)" "r2_within Within \(R^2\)") ///
	sfmt(0 0 0 3 3) ///
	style(tex) alignment(D{.}{.}{-1})
	
	

// TABLES AND GRAPHS IN RESPONSE LETTER 2 //

*-- response table 8: replicate table 1 excluding large networks
// only in 2008 so that durations are not censored
_pctile N, p(99.9)
reghdfe u er logN mis `Xd' `Xi' `Xj' `Xfe' if year==2008 & N<`r(r1)', absorb(lambda eta_4 sec_pre) vce(cluster firm)
est sto rtab8_1
estadd local pofe "Y" , replace
estadd local psfe "Y" , replace
estadd local cffe "Y" , replace

_pctile N, p(99.9)
reghdfe u er er_same4 logN logN_same4 mis mis_same4 `Xd' `Xi' `Xj' `Xfe' if year==2008 & N<`r(r1)', absorb(lambda eta_4 sec_pre) vce(cluster firm)
est sto rtab8_2
estadd local pofe "Y" , replace
estadd local psfe "Y" , replace
estadd local cffe "Y" , replace

_pctile N, p(99)
reghdfe u er logN mis `Xd' `Xi' `Xj' `Xfe' if year==2008 & N<`r(r1)', absorb(lambda eta_4 sec_pre) vce(cluster firm)
est sto rtab8_3
estadd local pofe "Y" , replace
estadd local psfe "Y" , replace
estadd local cffe "Y" , replace

_pctile N, p(99)
reghdfe u er er_same4 logN logN_same4 mis mis_same4 `Xd' `Xi' `Xj' `Xfe' if year==2008 & N<`r(r1)', absorb(lambda eta_4 sec_pre) vce(cluster firm)
est sto rtab8_4
estadd local pofe "Y" , replace
estadd local psfe "Y" , replace
estadd local cffe "Y" , replace

_pctile N, p(95)
reghdfe u er logN mis `Xd' `Xi' `Xj' `Xfe' if year==2008 & N<`r(r1)', absorb(lambda eta_4 sec_pre) vce(cluster firm)
est sto rtab8_5
estadd local pofe "Y" , replace
estadd local psfe "Y" , replace
estadd local cffe "Y" , replace

_pctile N, p(95)
reghdfe u er er_same4 logN logN_same4 mis mis_same4 `Xd' `Xi' `Xj' `Xfe' if year==2008 & N<`r(r1)', absorb(lambda eta_4 sec_pre) vce(cluster firm)
est sto rtab8_6
estadd local pofe "Y" , replace
estadd local psfe "Y" , replace
estadd local cffe "Y" , replace

_pctile N, p(90)
reghdfe u er logN mis `Xd' `Xi' `Xj' `Xfe' if year==2008 & N<`r(r1)', absorb(lambda eta_4 sec_pre) vce(cluster firm)
est sto rtab8_7
estadd local pofe "Y" , replace
estadd local psfe "Y" , replace
estadd local cffe "Y" , replace

_pctile N, p(90)
reghdfe u er er_same4 logN logN_same4 mis mis_same4 `Xd' `Xi' `Xj' `Xfe' if year==2008 & N<`r(r1)', absorb(lambda eta_4 sec_pre) vce(cluster firm)
est sto rtab8_8
estadd local pofe "Y" , replace
estadd local psfe "Y" , replace
estadd local cffe "Y" , replace
	
esttab rtab8_* using "${path_tables}/tab_r8.tex", replace ///
	keep(er* logN* `Xfe' `Xi' `Xj') ///
	order(er er_same* logN logN_same* `Xfe') ///
	label nomtitles nodepvars mlabels(none) collabels(none) ///
	cells(b(star fmt(3) label( )) se(par fmt(3) label( ))) ///
	starlevels(\sym{*} 0.1 \sym{**} 0.05 \sym{***} 0.01) ///
	scalars("cffe Closing firm FE" "pofe Pre-displacement occ.\ FE" "psfe Pre-displacement sector FE" "N \(N\)" "r2 \(R^2\)" "r2_within Within \(R^2\)") ///
	sfmt(0 0 0 3 3) ///
	style(tex) alignment(D{.}{.}{-1})


*-- response table 9: replicate table 2 excluding large networks
// only in 2008 so that durations are not censored
forval od = 1/4 {
	label var logN_same`od' "Log network size, same 4-digit occ."
}
_pctile N, p(99.9)
reghdfe u er_same4x er_same3x er_same2x er_same1x er_diff1 logN c.logN#c.Nsh_same4x c.logN#c.Nsh_same3x c.logN#c.Nsh_same2x c.logN#c.Nsh_same1x mis_same1 mis_same2 mis_same3 mis_same4 mis_diff1 `Xd' `Xi' `Xj' `Xfe' if year==2008 & N<`r(r1)', absorb(lambda eta_4 sec_pre) vce(cluster firm)
est sto rtab9_1
estadd local akmfe "Y", replace
estadd local i_pre "Y", replace
estadd local j_pre "Y", replace
estadd local psfe "Y", replace
estadd local pofe "Y", replace
estadd local cffe "Y", replace

_pctile N, p(99)
reghdfe u er_same4x er_same3x er_same2x er_same1x er_diff1 logN c.logN#c.Nsh_same4x c.logN#c.Nsh_same3x c.logN#c.Nsh_same2x c.logN#c.Nsh_same1x mis_same1 mis_same2 mis_same3 mis_same4 mis_diff1 `Xd' `Xi' `Xj' `Xfe' if year==2008 & N<`r(r1)', absorb(lambda eta_4 sec_pre) vce(cluster firm)
est sto rtab9_2
estadd local akmfe "Y", replace
estadd local i_pre "Y", replace
estadd local j_pre "Y", replace
estadd local psfe "Y", replace
estadd local pofe "Y", replace
estadd local cffe "Y", replace

_pctile N, p(95)
reghdfe u er_same4x er_same3x er_same2x er_same1x er_diff1 logN c.logN#c.Nsh_same4x c.logN#c.Nsh_same3x c.logN#c.Nsh_same2x c.logN#c.Nsh_same1x mis_same1 mis_same2 mis_same3 mis_same4 mis_diff1 `Xd' `Xi' `Xj' `Xfe' if year==2008 & N<`r(r1)', absorb(lambda eta_4 sec_pre) vce(cluster firm)
est sto rtab9_3
estadd local akmfe "Y", replace
estadd local i_pre "Y", replace
estadd local j_pre "Y", replace
estadd local psfe "Y", replace
estadd local pofe "Y", replace
estadd local cffe "Y", replace

_pctile N, p(90)
reghdfe u er_same4x er_same3x er_same2x er_same1x er_diff1 logN c.logN#c.Nsh_same4x c.logN#c.Nsh_same3x c.logN#c.Nsh_same2x c.logN#c.Nsh_same1x mis_same1 mis_same2 mis_same3 mis_same4 mis_diff1 `Xd' `Xi' `Xj' `Xfe' if year==2008 & N<`r(r1)', absorb(lambda eta_4 sec_pre) vce(cluster firm)
est sto rtab9_4
estadd local akmfe "Y", replace
estadd local i_pre "Y", replace
estadd local j_pre "Y", replace
estadd local psfe "Y", replace
estadd local pofe "Y", replace
estadd local cffe "Y", replace

esttab rtab9_* using "${path_tables}/tab_r9.tex", replace ///
	keep(er* logN) ///
	order(er* logN) ///
	label nomtitles nodepvars mlabels(none) collabels(none) ///
	cells(b(star fmt(3)) se(par fmt(3))) ///
	starlevels(\sym{*} 0.1 \sym{**} 0.05 \sym{***} 0.01) ///
	scalars("akmfe Network AKM FEs" "i_pre Pre-displacement worker characteristics" "j_pre Pre-displacement firm characteristics" "cffe Closing firm FE" "pofe Pre-displacement occ.\ FE" "psfe Pre-displacement sector FE" "N \(N\)" "r2 \(R^2\)" "r2_within Within \(R^2\)") ///
	sfmt(0 0 0 0 0 3 3) ///
	style(tex) alignment(D{.}{.}{-1})
forval od=1/4 {
	label var logN_same`od' "Log network size, same occ."
}


*-- response table 10: replicate table 3 excluding large networks
// only in 2008 so that durations are not censored
*- separate regressions
forval educ = 1/3 {
	_pctile N, p(99.9)
	reghdfe u er_same4x er_same3x er_same2x er_same1x er_diff1 logN c.logN#c.Nsh_same4x c.logN#c.Nsh_same3x c.logN#c.Nsh_same2x c.logN#c.Nsh_same1x mis_same1 mis_same2 mis_same3 mis_same4 mis_diff1 `Xd' `Xi' `Xj' `Xfe' if year==2008 & educ==`educ' & N<`r(r1)', absorb(lambda eta_4 sec_pre) vce(r)
	est sto rtab10_`educ'_1
	test er_same4x er_same3x er_same2x er_same1x
	estadd scalar F_joint = r(F)
	estadd scalar p_joint = r(p)
	estadd local akmfe "Y", replace
	estadd local i_pre "Y", replace
	estadd local j_pre "Y", replace
	estadd local psfe "Y", replace
	estadd local pofe "Y", replace
	estadd local cffe "Y", replace
	
	_pctile N, p(99)
	reghdfe u er_same4x er_same3x er_same2x er_same1x er_diff1 logN c.logN#c.Nsh_same4x c.logN#c.Nsh_same3x c.logN#c.Nsh_same2x c.logN#c.Nsh_same1x mis_same1 mis_same2 mis_same3 mis_same4 mis_diff1 `Xd' `Xi' `Xj' `Xfe' if year==2008 & educ==`educ' & N<`r(r1)', absorb(lambda eta_4 sec_pre) vce(r)
	est sto rtab10_`educ'_2
	test er_same4x er_same3x er_same2x er_same1x
	estadd scalar F_joint = r(F)
	estadd scalar p_joint = r(p)
	estadd local akmfe "Y", replace
	estadd local i_pre "Y", replace
	estadd local j_pre "Y", replace
	estadd local psfe "Y", replace
	estadd local pofe "Y", replace
	estadd local cffe "Y", replace
}

esttab rtab10_* using "${path_tables}/tab_r10.tex", replace ///
	keep(er* logN) ///
	order(er* logN) ///
	label nomtitles nodepvars mlabels(none) collabels(none) ///
	cells(b(star fmt(3)) se(par fmt(3))) ///
	starlevels(\sym{*} 0.1 \sym{**} 0.05 \sym{***} 0.01) ///
	scalars("akmfe Network AKM FEs" "i_pre Pre-displacement worker characteristics" "j_pre Pre-displacement firm characteristics" "cffe Closing firm FE" "pofe Pre-displacement occ.\ FE" "psfe Pre-displacement sector FE" "N \(N\)" "r2 \(R^2\)" "r2_within Within \(R^2\)" "F_joint Joint \(F\)-test" "p_joint \(p\)-value") ///
	sfmt(0 0 0 0 0 3 3) ///
	style(tex) alignment(D{.}{.}{-1})

*- pooled regression across education levels, results manually exported
_pctile N, p(99.9)
reghdfe u i.educ#c.(er_same4x er_same3x er_same2x er_same1x er_diff1 logN c.logN#c.Nsh_same4x c.logN#c.Nsh_same3x c.logN#c.Nsh_same2x c.logN#c.Nsh_same1x mis_same1 mis_same2 mis_same3 mis_same4 mis_diff1) `Xd' `Xi' `Xj' `Xfe' if year==2008 & N<`r(r1)', absorb(lambda eta_4 sec_pre) vce(r)

_pctile N, p(99)
reghdfe u i.educ#c.(er_same4x er_same3x er_same2x er_same1x er_diff1 logN c.logN#c.Nsh_same4x c.logN#c.Nsh_same3x c.logN#c.Nsh_same2x c.logN#c.Nsh_same1x mis_same1 mis_same2 mis_same3 mis_same4 mis_diff1) `Xd' `Xi' `Xj' `Xfe' if year==2008 & N<`r(r1)', absorb(lambda eta_4 sec_pre) vce(r)

_pctile N, p(95)
reghdfe u i.educ#c.(er_same4x er_same3x er_same2x er_same1x er_diff1 logN c.logN#c.Nsh_same4x c.logN#c.Nsh_same3x c.logN#c.Nsh_same2x c.logN#c.Nsh_same1x mis_same1 mis_same2 mis_same3 mis_same4 mis_diff1) `Xd' `Xi' `Xj' `Xfe' if year==2008 & N<`r(r1)', absorb(lambda eta_4 sec_pre) vce(r)

_pctile N, p(90)
reghdfe u i.educ#c.(er_same4x er_same3x er_same2x er_same1x er_diff1 logN c.logN#c.Nsh_same4x c.logN#c.Nsh_same3x c.logN#c.Nsh_same2x c.logN#c.Nsh_same1x mis_same1 mis_same2 mis_same3 mis_same4 mis_diff1) `Xd' `Xi' `Xj' `Xfe' if year==2008 & N<`r(r1)', absorb(lambda eta_4 sec_pre) vce(r)


*-- response graph 1: show histogram of network size
_pctile N, p(90 95 99 99.9)
local p90 =  r(r1)
local p95 =  r(r2)
local p99 = r(r3)
local p99_9 = r(r4)

hist N, xline(`p90' `p95' `p99' `p99_9') graphregion(color(white)) bgcolor(white) xtitle("Network size")
graph export "${path_graphs}/network_size_hist.pdf", replace as(pdf) name("Graph")
	
	
log close


*-- end code
